@@ -1,6 +1,7 @@
 package Test03::AnotherCommand;
 
 use MooseX::App::Command;
+extends qw(Test03CommandBase);
 
 use Moose::Util::TypeConstraints;
 
@@ -50,6 +51,11 @@ option 'split' => (
     cmd_split     => qr/;/i,
 );
 
+option 'count' => (
+    is            => 'rw',
+    cmd_count     => 1,
+);
+
 option ['extra1','extra2'] => (
     is            => 'rw',
 );
